==> mauticGIT-Test-20251111_133203.tar.gz: var/www/html/mauticGIT-Test/var/tmp/twig/5c/5cc5fadc613c14e464d39a3d09922025.php <==
<?php

use Twig\Environment;
use Twig\Error\LoaderError;
use Twig\Error\RuntimeError;
use Twig\Extension\CoreExtension;
use Twig\Extension\SandboxExtension;
use Twig\Markup;
use Twig\Sandbox\SecurityError;
use Twig\Sandbox\SecurityNotAllowedTagError;
use Twig\Sandbox\SecurityNotAllowedFilterError;
use Twig\Sandbox\SecurityNotAllowedFunctionError;
use Twig\Source;
use Twig\Template;
use Twig\TemplateWrapper;

/* @bundles/CoreBundle/Cache/ResultCacheHelper.php */
class __TwigTemplate_12887834cb48f4e00af08e1004c8c6f1 extends Template
{
    private Source $source;
    /**
     * @var array<string, Template>
     */
    private array $macros = [];

    public function __construct(Environment $env)
    {
        parent::__construct($env);

        $this->source = $this->getSourceContext();

        $this->parent = false;

        $this->blocks = [
        ];
    }

    protected function doDisplay(array $context, array $blocks = []): iterable
    {
        $macros = $this->macros;
        // line 1
        yield "<?php

declare(strict_types=1);

namespace Mautic\\CoreBundle\\Cache;

use Doctrine\\Common\\Cache\\CacheProvider;
use Doctrine\\Common\\Cache\\Psr6\\DoctrineProvider;
use Doctrine\\DBAL\\Cache\\QueryCacheProfile;
use Doctrine\\DBAL\\Configuration;
use Doctrine\\DBAL\\Connection;
use Doctrine\\DBAL\\Query\\QueryBuilder;
use Doctrine\\DBAL\\Result;
use Doctrine\\ORM\\Query;

class ResultCacheHelper
{
    /**
     * @return bool Returns true if cache was available and enabled on the \$query
     */
    public static function enableOrmQueryCache(Query \$query, ResultCacheOptions \$resultCacheOptions): bool
    {
        \$cache = self::getCache(\$query->getEntityManager()->getConfiguration());

        if (!\$cache) {
            return false;
        }

        \$query->setResultCacheProfile(self::createCacheProfile(\$resultCacheOptions, \$cache));

        return true;
    }

    /**
     * Executes the query using cache (if available) and returns its result.
     */
    public static function executeCachedDbalQuery(Connection \$connection, QueryBuilder \$queryBuilder, ResultCacheOptions \$resultCacheOptions): Result
    {
        \$cache = self::getCache(\$connection->getConfiguration());

        if (!\$cache) {
            return \$queryBuilder->executeQuery();
        }

        return \$connection->executeCacheQuery(
            \$queryBuilder->getSQL(),
            \$queryBuilder->getParameters(),
            \$queryBuilder->getParameterTypes(),
            self::createCacheProfile(\$resultCacheOptions, \$cache)
        );
    }

    public static function getCache(Configuration \$configuration): ?CacheProvider
    {
        \$cache = \$configuration->getResultCache();

        if (!\$cache) {
            return null;
        }

        \$cache = DoctrineProvider::wrap(\$cache);

        if (!\$cache instanceof CacheProvider) {
            return null;
        }

        return \$cache;
    }

    private static function createCacheProfile(ResultCacheOptions \$resultCacheOptions, CacheProvider \$cache): QueryCacheProfile
    {
        \$cache = clone \$cache;
        \$cache->setNamespace(\$resultCacheOptions->getNamespace());

        return new QueryCacheProfile((int) \$resultCacheOptions->getTtl(), \$resultCacheOptions->getId(), \$cache);
    }
}
";
        yield from [];
    }

    /**
     * @codeCoverageIgnore
     */
    public function getTemplateName(): string
    {
        return "@bundles/CoreBundle/Cache/ResultCacheHelper.php";
    }

    /**
     * @codeCoverageIgnore
     */
    public function getDebugInfo(): array
    {
        return array (  42 => 1,);
    }

    public function getSourceContext(): Source
    {
        return new Source("", "@bundles/CoreBundle/Cache/ResultCacheHelper.php", "/var/www/mautic-ktn/app/bundles/CoreBundle/Cache/ResultCacheHelper.php");
    }
}

==> mauticGIT-Test-20260116_092227.tar.gz: var/www/html/mauticGIT-Test/var/tmp/twig/5c/5cc5fadc613c14e464d39a3d09922025.php <==
<?php

use Twig\Environment;
use Twig\Error\LoaderError;
use Twig\Error\RuntimeError;
use Twig\Extension\CoreExtension;
use Twig\Extension\SandboxExtension;
use Twig\Markup;
use Twig\Sandbox\SecurityError;
use Twig\Sandbox\SecurityNotAllowedTagError;
use Twig\Sandbox\SecurityNotAllowedFilterError;
use Twig\Sandbox\SecurityNotAllowedFunctionError;
use Twig\Source;
use Twig\Template;
use Twig\TemplateWrapper;

/* @bundles/CoreBundle/Cache/ResultCacheHelper.php */
class __TwigTemplate_12887834cb48f4e00af08e1004c8c6f1 extends Template
{
    private Source $source;
    /**
     * @var array<string, Template>
     */
    private array $macros = [];

    public function __construct(Environment $env)
    {
        parent::__construct($env);

        $this->source = $this->getSourceContext();

        $this->parent = false;

        $this->blocks = [
        ];
    }

    protected function doDisplay(array $context, array $blocks = []): iterable
    {
        $macros = $this->macros;
        // line 1
        yield "<?php

declare(strict_types=1);

namespace Mautic\\CoreBundle\\Cache;

use Doctrine\\Common\\Cache\\CacheProvider;
use Doctrine\\Common\\Cache\\Psr6\\DoctrineProvider;
use Doctrine\\DBAL\\Cache\\QueryCacheProfile;
use Doctrine\\DBAL\\Configuration;
use Doctrine\\DBAL\\Connection;
use Doctrine\\DBAL\\Query\\QueryBuilder;
use Doctrine\\DBAL\\Result;
use Doctrine\\ORM\\Query;

class ResultCacheHelper
{
    /**
     * @return bool Returns true if cache was available and enabled on the \$query
     */
    public static function enableOrmQueryCache(Query \$query, ResultCacheOptions \$resultCacheOptions): bool
    {
        \$cache = self::getCache(\$query->getEntityManager()->getConfiguration());

        if (!\$cache) {
            return false;
        }

        \$query->setResultCacheProfile(self::createCacheProfile(\$resultCacheOptions, \$cache));

        return true;
    }

    /**
     * Executes the query using cache (if available) and returns its result.
     */
    public static function executeCachedDbalQuery(Connection \$connection, QueryBuilder \$queryBuilder, ResultCacheOptions \$resultCacheOptions): Result
    {
        \$cache = self::getCache(\$connection->getConfiguration());

        if (!\$cache) {
            return \$queryBuilder->executeQuery();
        }

        return \$connection->executeCacheQuery(
            \$queryBuilder->getSQL(),
            \$queryBuilder->getParameters(),
            \$queryBuilder->getParameterTypes(),
            self::createCacheProfile(\$resultCacheOptions, \$cache)
        );
    }

    public static function getCache(Configuration \$configuration): ?CacheProvider
    {
        \$cache = \$configuration->getResultCache();

        if (!\$cache) {
            return null;
        }

        \$cache = DoctrineProvider::wrap(\$cache);

        if (!\$cache instanceof CacheProvider) {
            return null;
        }

        return \$cache;
    }

    private static function createCacheProfile(ResultCacheOptions \$resultCacheOptions, CacheProvider \$cache): QueryCacheProfile
    {
        \$cache = clone \$cache;
        \$cache->setNamespace(\$resultCacheOptions->getNamespace());

        return new QueryCacheProfile((int) \$resultCacheOptions->getTtl(), \$resultCacheOptions->getId(), \$cache);
    }
}
";
        yield from [];
    }

    /**
     * @codeCoverageIgnore
     */
    public function getTemplateName(): string
    {
        return "@bundles/CoreBundle/Cache/ResultCacheHelper.php";
    }

    /**
     * @codeCoverageIgnore
     */
    public function getDebugInfo(): array
    {
        return array (  42 => 1,);
    }

    public function getSourceContext(): Source
    {
        return new Source("", "@bundles/CoreBundle/Cache/ResultCacheHelper.php", "/var/www/html/mauticGIT-Test/app/bundles/CoreBundle/Cache/ResultCacheHelper.php");
    }
}
